//
// Stepper control - Variables and constants
//

//
//Define special key values
//

const unsigned char Left=10;	//Left key
const unsigned char Right=11;	//Right key
const unsigned char Up=12;	//Up key
const unsigned char Down=13;	//Down key
const unsigned char Ok=14;	//OK key (#)
const unsigned char Abort=15;	//Abort key (*)
const unsigned char NoKey=0xff;	//No keypress

const int LCDPORT=&PORTD;	//Set display to Port D
const int LCDRSPORT=&PORTD;
const int LCDRSBIT=1;
const int LCDRWPORT=&PORTD;
const int LCDRWBIT=2;
const int LCDEPORT=&PORTD;
const int LCDEBIT=3;

const int Row1Port=&PORTA;	//Set keypad rows to Port C
const int Row2Port=&PORTA;
const int Row3Port=&PORTA;
const int Row4Port=&PORTA;
const int Col1Port=&PORTB;	//Set keypad cols to Port C
const int Col2Port=&PORTB;
const int Col3Port=&PORTB;
const int Col4Port=&PORTB;
const int Row1Bit=1;		//Set keypad row bits
const int Row2Bit=2;
const int Row3Bit=3;
const int Row4Bit=5;
const int Col1Bit=4;		//Set keypad col bits
const int Col2Bit=5;
const int Col3Bit=6;
const int Col4Bit=7;
const int KeyPadRelease=0;	//Set driving continuous

//
// Define display strings
//

const unsigned char EnterString[]="    Prv/Nxt   OK";
const unsigned char OkString[]="<   Prv/Nxt    >";
const unsigned char ExitString[]="-     Exit     +";
const unsigned char ExitString2[]="      Exit      ";
const unsigned char ExecuteString[]="-   Execute?   +";

//
// Declare structure definitions
//

struct Parameters		//Define the parameter structure
{
 unsigned char CW;		//1 if +ve step is CW; 0 if CCW
 				//N.B. This must be the first var in the struct
 char Rate;			//Ramp Rate
 int Ratio;			//Worm ratio (max 5000)
 int Divs;			//Number of divisions for divs mode
 long Degrees;			//Number of degrees*1000 for degrees mode
 int JogSlow;			//Jog slow speed
 int JogFast;			//Jog fast speed
 int Slow;			//Slow speed
 int Fast;			//Fast speed
 int Lash;			//Backlash (max 99 steps)
 int Current;			//Current (max 2.0 amps - 20 in fixed point)
 int Idle;			//Idle current - percent of Current (0-100)
 char JogRate;			//Slow ramp rate
};

const char parSize=25;		//Size of the Parameters structure in bytes
const char maxParamSet=4; 	//Max number of parameter sets
 
// GLOBAL VARIABLES

Parameters Params;		//Define the Params structure
unsigned char *CharPtr;		//Define a character pointer
unsigned char dutyCycle;	//Calculated duty cycle value
int duty;			//Duty cycle rough pad
unsigned char newKey;		//Current keystroke
unsigned char oldKey;		//Last keystroke
unsigned int delay;		//current delay value
unsigned int slow;		//current min speed
unsigned int fast;		//current max speed
char rate;			//current acceleration rate
char direction;			//current direction
long stepsPerRev;		//Number of halfsteps for 360 degrees
long stepNumber;		//current halfstep number (global position)
long position;			//current position (step number or degrees)
long increment;			//current increment (# of steps or degrees)
char currentParamSet;		//current set of parameters (0 through maxParamSet)
				//Define keystroke translation table
const unsigned char keys[16]={6, 3, Ok, 9, Right, Left, Down, Up,
				 4, 1, Abort, 7, 5, 2, 0, 8};

